@@ -6,7 +6,7 @@ import ast
 import dataclasses
 import logging
 from configparser import ConfigParser
-from typing import Tuple, Type, Dict, get_origin, Union, get_args, List, Any, Optional
+from typing import Tuple, Type, Dict, get_origin, Union, get_args, Any, Optional
 
 from autoconfiguration.exceptions.data_type_errors import (
     UnableToConvertConfigValueToTypeError,
@@ -28,7 +28,9 @@ class _HasDefaultValue:
 HAS_DEFAULT_VALUE = _HasDefaultValue()
 
 
-def create_config_instance(config_class: Type, config_files: Tuple[str, ...]):
+def create_config_instance(
+    config_class: Type[Any], config_files: Tuple[str, ...]
+) -> Any:
     """
     Creates an instance of the passed config class with the values of the passed
     config files. The data types of the config class and the types of its attributes
@@ -67,7 +69,9 @@ def _valid_name(name: str) -> str:
     return name.replace("-", "_")
 
 
-def _create_config_class_instance(config_class: Type, sections: Dict):
+def _create_config_class_instance(
+    config_class: Type[Any], sections: Dict[str, Dict[str, str]]
+) -> Any:
     """
     Creates and returns the instance of the passed config class.
 
@@ -98,7 +102,9 @@ def _create_config_class_instance(config_class: Type, sections: Dict):
     return instance
 
 
-def _get_value_of_field(field: dataclasses.Field, sections: Dict):
+def _get_value_of_field(
+    field: dataclasses.Field, sections: Dict[str, Dict[str, str]]
+) -> Any:
     """
     Returns the value of a field of the config class. The value of the field is
     returned if the passed sections contain the field. None is returned if the field
@@ -123,7 +129,9 @@ def _get_value_of_field(field: dataclasses.Field, sections: Dict):
     return HAS_DEFAULT_VALUE if _has_default(field) else MISSING_VALUE
 
 
-def _get_values_of_sub_fields(field: dataclasses.Field, sections: Dict) -> Dict:
+def _get_values_of_sub_fields(
+    field: dataclasses.Field, sections: Dict[str, Dict[str, str]]
+) -> Dict[str, Any]:
     """
     Returns the values of all fields of the passed field. The value of the field is
     used if the passed sections contain the field. None is used if the field
@@ -152,7 +160,7 @@ def _get_values_of_sub_fields(field: dataclasses.Field, sections: Dict) -> Dict:
     return values
 
 
-def _convert_to_correct_type(value: str, expected_type: Type) -> Any:
+def _convert_to_correct_type(value: str, expected_type: Type[Any]) -> Any:
     """
     Tries to convert the passed value to the passed expected type.
 
@@ -175,7 +183,7 @@ def _convert_to_correct_type(value: str, expected_type: Type) -> Any:
     return result
 
 
-def _is_optional(annotation_type: Type) -> bool:
+def _is_optional(annotation_type: Type[Any]) -> bool:
     """
     Checks if the passed type is Optional.
 
