@@ -5,5 +5,5 @@ from autoconfiguration.exceptions.base_error import ConfigBaseError
 class NoConfigFilesFoundError(ConfigBaseError):
     """Raised if none of the configuration files exist."""
 
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__("No configuration files could be found!")
