@@ -1,6 +1,6 @@
 """Contains helper functions to modify classes that overwrite specific methods."""
 import dataclasses
-from typing import Type, Dict
+from typing import Type, Dict, Any
 
 from autoconfiguration.exceptions.config_class_errors import ConfigClassAttributeError
 
@@ -18,7 +18,7 @@ class Constants:
     config_instance = None
 
 
-def make_singleton(obj: Type):
+def make_singleton(obj: Type[Any]) -> None:
     """
     Modifies the passed type to ensure that only one instance of the type can be
     created.
@@ -26,7 +26,8 @@ def make_singleton(obj: Type):
     :param obj: The type that should be a singleton
     """
 
-    def __new__(cls, *args, **kwargs):
+    def __new__(cls: Type[Any], *args: Any, **kwargs: Any) -> Any:
+        # pylint: disable=unused-argument
         if not hasattr(Constants, "config_instance") or not Constants.config_instance:
             Constants.config_instance = object.__new__(cls)
         return Constants.config_instance
@@ -34,7 +35,9 @@ def make_singleton(obj: Type):
     setattr(obj, "__new__", __new__)
 
 
-def add_contains_getattribute_getitem_get_methods_to(cls, available_attributes: Dict):
+def add_contains_getattribute_getitem_get_methods_to(
+    cls: Type[Any], available_attributes: Dict[str, Any]
+) -> None:
     """
     Adds implementations to the passed instance of a class for the following methods:
 
@@ -58,7 +61,7 @@ def add_contains_getattribute_getitem_get_methods_to(cls, available_attributes:
         else default_value,
     )
 
-    def __getattribute__(self, item):
+    def __getattribute__(self: Any, item: str) -> Any:
         value = object.__getattribute__(self, item)
         if value == MISSING_VALUE:
             raise ConfigClassAttributeError(item)
@@ -67,7 +70,7 @@ def add_contains_getattribute_getitem_get_methods_to(cls, available_attributes:
     setattr(cls, "__getattribute__", __getattribute__)
 
 
-def freeze_class(cls):
+def freeze_class(cls: Type[Any]) -> None:
     """
     Freezes a class by adding implementations for the following methods:
     - __delattr__: Raises a FrozenInstanceError
@@ -76,12 +79,12 @@ def freeze_class(cls):
     :param cls: The class that should be frozen
     """
 
-    def __delattr__(self, name):
+    def __delattr__(self: Any, name: str) -> None:
         raise dataclasses.FrozenInstanceError()
 
     setattr(cls, "__delattr__", __delattr__)
 
-    def __setattr__(self, name, value):
+    def __setattr__(self: Any, name: str, value: Any) -> None:
         raise dataclasses.FrozenInstanceError()
 
     setattr(cls, "__setattr__", __setattr__)
